from setuptools import setup, find_packages

setup(name='pyboto3',
      version='1.1',
      packages=find_packages(),
      description='Pythonic Interface for AWS boto3 that gives you autocomplete on every service',
      author='Gehad Shaat',
      author_email='',
      url='https://github.com/gehadshaat/pyboto3',
      py_modules=['pyboto3'],
      install_requires=[],
      license='MIT License',
      zip_safe=True,
      keywords='aws boto3 pythonic python',
      classifiers=[])
